=============
API reference
=============

This is the API reference for the zfit fitting package.
Most classes and functions are documented with docstrings, but don't hesitate to contact us if this documentation is
insufficient!

.. attention::
    This document is in the process of being built. If you want to add to it you can simply click the 'Edit this
    page' button at the top of the right column on which ever page you'd like to change. You need a
    `GitHub <https://github.com/>`_ account to do this.

.. toctree::
    :maxdepth: 3

    zfit.constraint
    zfit.data
    zfit.dimension
    zfit.exception
    zfit.func
    zfit.loss
    zfit.minimize
    zfit.param
    zfit.pdf
    zfit.util.typing
    zfit.sample
    zfit.settings
